// SPDX-License-Identifier: MIT
/*
 * Copyright (c) 2023 Atmark Techno,Inc.
 */

#include <getopt.h>
#include <stdio.h>

#include "device-info.h"

char *version = "1.0-r0";
bool print_env = false;

static struct option long_options[] = {
	{"abos-version",	no_argument,	NULL,	'a'},
	{"env",	no_argument,	NULL,	'e'},
	{"help",	no_argument,	NULL,	'h'},
	{"mac-address",	no_argument,	NULL,	'm'},
	{"product",	no_argument,	NULL,	'p'},
	{"serial",	no_argument,	NULL,	's'},
	{"version",	no_argument,	NULL,	'v'},
	{0,			0,				0,	0}
};

static void print_version(char *argv0) {
	printf("%s version %s\n", argv0, version);
}

static void help(char *argv0) {
	printf("Usage: %s [options]\n", argv0);
	printf("Options:\n");
	printf("  -a, --abos-version: show ABOS version\n");
	printf("  -e, --env: show as environmental variables\n");
	printf("  -h, --help: show this help\n");
	printf("  -m, --mac-address: print the MAC address of this board\n");
	printf("  -p, --product: print the product name of this board\n");
	printf("  -s, --serial: print the serial number of this board\n");
	printf("  -v, --version: show device-info version\n");
}

int main(int argc, char *argv[])
{
	int c;
	int option_index = 0;
	int ret = 0;

	while ((c = getopt_long(argc, argv, "aehmpsv", long_options, &option_index)) > 0) {

		switch (c) {
			case 'a':
				ret = print_abos_version();
				break;
			case 'e':
				print_env = true;
				break;
			case 'h':
				help(argv[0]);
				break;
			case 'm':
				ret = print_mac_addr();
				break;
			case 'p':
				ret = print_product_name();
				break;
			case 's':
				ret = print_serial_num();
				break;
			case 'v':
				print_version(argv[0]);
				break;
			default:
				fprintf(stderr, "Execute '%s --help'.\n", argv[0]);
				ret = 1;
				break;
		}
		if (ret != 0) {
			break;
		}
	}
	if (argc == 1) {
    	help(argv[0]);
	}

	if (optind < argc) {
		printf("Unrecognized option: ");
		while (optind < argc)
			printf("%s ", argv[optind++]);
		printf("\n");
	}

	return ret;
}
